# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-15 15:06
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('request_logger', '0002_auto_20170918_1506'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userrequest',
            name='user',
            field=models.IntegerField(null=True),
        ),
    ]
