# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-09-18 15:06
from __future__ import unicode_literals

from django.db import migrations
import request_logger.models


class Migration(migrations.Migration):

    dependencies = [
        ('request_logger', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='userrequest',
            name='content_length',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='content_type',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='encoding',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_accept',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_accept_encoding',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_accept_language',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_host',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_referer',
            field=request_logger.models.TruncatingCharField(max_length=2047),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='http_user_agent',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='method',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='path',
            field=request_logger.models.TruncatingCharField(max_length=2047),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='remote_addr',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='remote_host',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='remote_user',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='scheme',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='server_name',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
        migrations.AlterField(
            model_name='userrequest',
            name='server_port',
            field=request_logger.models.TruncatingCharField(max_length=255),
        ),
    ]
