# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-11-16 09:43
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import request_logger.models


class Migration(migrations.Migration):

    replaces = [('request_logger', '0001_initial'), ('request_logger', '0002_auto_20170918_1506'), ('request_logger', '0003_auto_20171115_1506')]

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='UserRequest',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('timestamp', models.DateTimeField(auto_now_add=True)),
                ('path', request_logger.models.TruncatingCharField(max_length=2047)),
                ('method', request_logger.models.TruncatingCharField(max_length=255)),
                ('scheme', request_logger.models.TruncatingCharField(max_length=255)),
                ('body', models.TextField()),
                ('content_length', request_logger.models.TruncatingCharField(max_length=255)),
                ('content_type', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_accept', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_accept_encoding', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_accept_language', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_host', request_logger.models.TruncatingCharField(max_length=255)),
                ('http_referer', request_logger.models.TruncatingCharField(max_length=2047)),
                ('http_user_agent', request_logger.models.TruncatingCharField(max_length=255)),
                ('remote_addr', request_logger.models.TruncatingCharField(max_length=255)),
                ('remote_host', request_logger.models.TruncatingCharField(max_length=255)),
                ('remote_user', request_logger.models.TruncatingCharField(max_length=255)),
                ('server_name', request_logger.models.TruncatingCharField(max_length=255)),
                ('server_port', request_logger.models.TruncatingCharField(max_length=255)),
                ('post_data', models.TextField()),
                ('get_data', models.TextField()),
                ('cookies', models.TextField()),
                ('encoding', request_logger.models.TruncatingCharField(max_length=255)),
                ('is_ajax', models.BooleanField()),
                ('user', models.IntegerField(null=True)),
            ],
        ),
    ]
