#!/usr/bin/env python
# vi: et sw=2 fileencoding=utf-8

from __future__ import unicode_literals

from django.apps import AppConfig


class RequestLoggerConfig(AppConfig):
  name = "request_logger"
  verbose_name = "Request logger for django"


  # class RequestLoggerConfig


